@@ -16,11 +16,7 @@
  * License along with this program.
  * If not, see http://www.gnu.org/licenses/.
  */
+pub mod json_writer;
 pub mod scalar;
 pub mod table;
-
-#[cfg(not(feature = "datafusion"))]
-mod _scalar;
-
-pub mod json_writer;
 pub mod tasks;
