@@ -22,9 +22,7 @@ extern crate lazy_static;
 mod util;
 use std::sync::Once;
 
-use crate::util::vegajs_runtime::{
-    vegajs_runtime, ExportImageFormat, ExportUpdate, ExportUpdateBatch, ExportUpdateNamespace,
-};
+use crate::util::vegajs_runtime::{vegajs_runtime, ExportImageFormat};
 use datafusion::scalar::ScalarValue;
 use rstest::rstest;
 use std::collections::HashMap;
@@ -37,7 +35,9 @@ use vegafusion_core::data::table::VegaFusionTable;
 
 use vegafusion_core::planning::plan::SpecPlan;
 
-use vegafusion_core::planning::watch::{Watch, WatchNamespace, WatchPlan};
+use vegafusion_core::planning::watch::{
+    ExportUpdate, ExportUpdateBatch, ExportUpdateNamespace, Watch, WatchNamespace, WatchPlan,
+};
 use vegafusion_core::proto::gen::tasks::TaskGraph;
 use vegafusion_core::spec::chart::ChartSpec;
 use vegafusion_core::task_graph::graph::ScopedVariable;
@@ -119,7 +119,8 @@ mod test_custom_specs {
         case("custom/grouped_bar_chart_with_error_bars", 0.001),
         case("custom/one_dot_per_zipcode", 0.001),
         case("custom/ridgeline", 0.001),
-        case("custom/binned_scatter", 0.001)
+        case("custom/binned_scatter", 0.001),
+        case("custom/seattle_temps_heatmap", 0.001)
     )]
     fn test_image_comparison(spec_name: &str, tolerance: f64) {
         println!("spec_name: {}", spec_name);
@@ -447,10 +448,7 @@ mod test_vegalite_specs {
         case("vegalite/circle_flatten", 0.001),
         case("vegalite/circle_github_punchcard", 0.001),
         case("vegalite/circle_labelangle_orient_signal", 0.001),
-
-        // "Ambiguous reference to field" error related to
-        // https://github.com/apache/arrow-datafusion/issues/1411
-        // case("vegalite/circle_natural_disasters", 0.001),
+        case("vegalite/circle_natural_disasters", 0.001),
         case("vegalite/circle_opacity", 0.001),
         case("vegalite/circle_scale_quantile", 0.001),
         case("vegalite/circle_scale_quantize", 0.001),
@@ -561,10 +559,7 @@ mod test_vegalite_specs {
         case("vegalite/joinaggregate_mean_difference_by_year", 0.001),
         case("vegalite/joinaggregate_mean_difference", 0.001),
         case("vegalite/joinaggregate_percent_of_total", 0.001),
-
-        // // (DataFusion bug https://github.com/apache/arrow-datafusion/issues/1411)
-        // case("joinaggregate_residual_graph", 0.001),
-
+        case("vegalite/joinaggregate_residual_graph", 0.001),
         case("vegalite/layer_arc_label", 0.001),
         case("vegalite/layer_bar_annotations", 0.001),
         case("vegalite/layer_bar_circle_grouped", 0.001),
@@ -592,8 +587,8 @@ mod test_vegalite_specs {
         case("vegalite/layer_line_datum_rule_datetime", 0.001),
         case("vegalite/layer_line_datum_rule", 0.001),
 
-        // (Offset in start position of outline dash)
-        case("vegalite/layer_line_errorband_2d_horizontal_borders_strokedash", 0.5),
+        // // (Offset in start position of outline dash)
+        // case("vegalite/layer_line_errorband_2d_horizontal_borders_strokedash", 0.5),
 
         case("vegalite/layer_line_errorband_pre_aggregated", 0.001),
         case("vegalite/layer_line_mean_point_raw", 0.001),
@@ -1087,6 +1082,7 @@ fn load_expected_watch_plan(spec_name: &str) -> WatchPlan {
     serde_json::from_str(&comm_plan_str).unwrap()
 }
 
+#[allow(dead_code)]
 fn write_updated_watch_plan(spec_name: &str, plan: &WatchPlan) {
     let watch_plan_path = format!("{}/tests/specs/{}.comm_plan.json", crate_dir(), spec_name);
     let watch_plan_path = std::path::Path::new(&watch_plan_path);
@@ -1117,6 +1113,7 @@ async fn check_spec_sequence(
 ) {
     // Initialize runtime
     let vegajs_runtime = vegajs_runtime();
+    let local_tz = vegajs_runtime.nodejs_runtime.local_timezone().unwrap();
 
     let spec_plan = SpecPlan::try_new(&full_spec).unwrap();
 
@@ -1139,7 +1136,7 @@ async fn check_spec_sequence(
     );
 
     // Build task graph
-    let tasks = spec_plan.server_spec.to_tasks().unwrap();
+    let tasks = spec_plan.server_spec.to_tasks(&local_tz).unwrap();
     let mut task_graph = TaskGraph::new(tasks, &task_scope).unwrap();
     let task_graph_mapping = task_graph.build_mapping();
 
@@ -1197,7 +1194,7 @@ async fn check_spec_sequence(
         .unwrap();
 
     // Save exported PNGs
-    let png_name = spec_name.replace("/", "-");
+    let png_name = spec_name.replace('/', "-");
     for (i, (export_image, _)) in export_sequence_results.iter().enumerate() {
         export_image
             .save(
