@@ -30,6 +30,7 @@ use vegafusion_core::planning::stitch::stitch_specs;
 #[tokio::test(flavor = "multi_thread")]
 async fn test_extract_server_data() {
     let mut spec = spec1();
+    let local_tz = "America/New_York";
 
     // Get full spec's scope
     let mut task_scope = spec.to_task_scope().unwrap();
@@ -66,7 +67,7 @@ async fn test_extract_server_data() {
     let client_stubs: Vec<_> = client_inputs.difference(&client_defs).collect();
     println!("client_stubs: {:?}", client_stubs);
 
-    let tasks = server_spec.to_tasks().unwrap();
+    let tasks = server_spec.to_tasks(local_tz).unwrap();
     let graph = Arc::new(TaskGraph::new(tasks, &task_scope).unwrap());
     let mapping = graph.build_mapping();
     // println!("{:#?}", mapping);
@@ -148,6 +149,7 @@ async fn try_split_domain() {
     println!("{}", serde_json::to_string_pretty(&spec).unwrap())
 }
 
+#[allow(dead_code)]
 fn spec1() -> ChartSpec {
     serde_json::from_str(r##"
 {
@@ -1001,6 +1003,7 @@ fn spec1() -> ChartSpec {
 }
 
 // Data and scale nested into first group
+#[allow(dead_code)]
 fn spec2() -> ChartSpec {
     serde_json::from_str(r##"{
   "$schema": "https://vega.github.io/schema/vega/v5.json",
@@ -1855,6 +1858,7 @@ fn spec2() -> ChartSpec {
 }"##).unwrap()
 }
 
+#[allow(dead_code)]
 fn weather_spec() -> ChartSpec {
     serde_json::from_str(r##"
 {
@@ -1954,11 +1958,13 @@ fn weather_spec() -> ChartSpec {
   ],
   "legends": [
     {"title": "Weather type", "fill": "color", "symbolType": "square"}
+
   ]
 }
     "##).unwrap()
 }
 
+#[allow(dead_code)]
 fn histogram_responsive() -> ChartSpec {
     serde_json::from_str(r##"
 {
@@ -2513,6 +2519,7 @@ fn histogram_responsive() -> ChartSpec {
 }
 
 // Data and scale nested into first group
+#[allow(dead_code)]
 fn sorted_bar_spec() -> ChartSpec {
     serde_json::from_str(r##"
 {
@@ -2629,6 +2636,7 @@ fn sorted_bar_spec() -> ChartSpec {
 }
 
 // Data and scale nested into first group
+#[allow(dead_code)]
 fn cars_scatter_spec() -> ChartSpec {
     serde_json::from_str(r##"
 {
