@@ -22,7 +22,7 @@ use regex::Regex;
 use serde::{de::DeserializeOwned, Deserialize, Serialize};
 use serde_json::{json, Value};
 use std::collections::HashMap;
-use std::convert::TryFrom;
+
 use std::io::{Read, Write};
 use std::ops::Deref;
 use std::process::{Child, Command, Stdio};
@@ -38,9 +38,9 @@ use itertools::Itertools;
 use vegafusion_core::data::scalar::ScalarValueHelpers;
 use vegafusion_core::data::table::VegaFusionTable;
 
-use vegafusion_core::planning::watch::{Watch, WatchNamespace, WatchValue};
+use vegafusion_core::planning::watch::{ExportUpdateBatch, Watch, WatchNamespace, WatchValue};
 use vegafusion_core::proto::gen::expression::Expression;
-use vegafusion_core::proto::gen::tasks::VariableNamespace;
+
 use vegafusion_core::spec::chart::ChartSpec;
 use vegafusion_core::spec::transform::TransformSpec;
 
@@ -193,11 +193,16 @@ impl NodeJsRuntime {
         let s = String::from_utf8(Vec::from(&bytes_read[start_index..end_index])).unwrap();
         s.trim().to_string()
     }
+
+    pub fn local_timezone(&self) -> Result<String> {
+        self.execute_statement("Intl.DateTimeFormat().resolvedOptions().timeZone")
+            .map(|tz| tz.trim_matches('\'').to_string())
+    }
 }
 
 #[derive(Clone)]
 pub struct VegaJsRuntime {
-    nodejs_runtime: Arc<NodeJsRuntime>,
+    pub nodejs_runtime: Arc<NodeJsRuntime>,
 }
 
 impl VegaJsRuntime {
@@ -250,7 +255,7 @@ impl VegaJsRuntime {
     }
 
     /// Function to evaluate a full Vega spec and return requested data and signal values
-    pub fn eval_spec(&self, spec: &Value, watches: &Vec<Watch>) -> Result<Vec<WatchValue>> {
+    pub fn eval_spec(&self, spec: &Value, watches: &[Watch]) -> Result<Vec<WatchValue>> {
         let script = format!(
             r#"await VegaUtils.evalSpec({}, {})"#,
             serde_json::to_string(spec)?,
@@ -293,7 +298,7 @@ impl VegaJsRuntime {
         }];
 
         // Evaluate spec and extract signal value
-        let watches = self.eval_spec(&spec, &watches)?;
+        let watches = self.eval_spec(&spec, watches.as_slice())?;
         let scalar_value = ScalarValue::from_json(&watches[0].value)?;
         Ok(scalar_value)
     }
@@ -546,35 +551,6 @@ fn to_byte(i: f32) -> u8 {
     }
 }
 
-#[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
-#[serde(rename_all = "lowercase")]
-pub enum ExportUpdateNamespace {
-    Signal,
-    Data,
-}
-
-impl TryFrom<VariableNamespace> for ExportUpdateNamespace {
-    type Error = VegaFusionError;
-
-    fn try_from(value: VariableNamespace) -> Result<Self> {
-        match value {
-            VariableNamespace::Signal => Ok(Self::Signal),
-            VariableNamespace::Data => Ok(Self::Data),
-            _ => Err(VegaFusionError::internal("Scale namespace not supported")),
-        }
-    }
-}
-
-#[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
-pub struct ExportUpdate {
-    pub namespace: ExportUpdateNamespace,
-    pub name: String,
-    pub scope: Vec<u32>,
-    pub value: Value,
-}
-
-pub type ExportUpdateBatch = Vec<ExportUpdate>;
-
 lazy_static! {
     static ref NODE_JS_RUNTIME: Arc<NodeJsRuntime> = Arc::new(NodeJsRuntime::try_new().unwrap());
 }
@@ -583,5 +559,5 @@ pub fn vegajs_runtime() -> VegaJsRuntime {
 }
 
 fn unquote_path(path: &str) -> String {
-    path.replace(r#"\"#, r#"\\"#)
+    path.replace('\\', r#"\\"#)
 }
